<?php

class UriClimate extends Module
{
    public function __construct()
	{
        $this->name = 'uriclimate';
        $this->version = '1.0.0';
        $this->author = 'urimarti';
        parent::__construct();
        $this->displayName = $this->l('Digital #Climate Strike');
        $this->description = $this->l('Súmate a la causa de Digital #Climate Strike');
        $this->controllers = array('default');
        $this->bootstrap = 1;
    }

    public function install()
	{
		$data = array(
			'cookie' => 1,
			'analytics' => false,
			'show' => 1,
			'full' => 1,
			'close' => 1,
		);
		if(
			!Configuration::updateValue('URI_CLIMATE', serialize($data)) ||
			!parent::install() ||
			!$this->registerHook('displayFooter')
		){
			return false;
		} else {
			return true;
		}
    }
	
    public function uninstall()
	{
		if(
			!Configuration::deleteByName('URI_CLIMATE') ||
			!parent::uninstall() ||
			!$this->unregisterHook('displayFooter')
		){
			$this->_clearCache('footer.tpl');
			return false;
		} else {
			$this->_clearCache('footer.tpl');
			return true;
		}
    }

    public function getContent()
	{
        return $this->postProcess() . $this->getForm();
    }

    private function postProcess()
	{
        if (Tools::isSubmit('submit')) {
			$data = array(
				'cookie' => (int)Tools::getValue('cookie'),
				'analytics' => (int)Tools::getValue('analytics'),
				'show' => (int)Tools::getValue('show'),
				'full' => (int)Tools::getValue('full'),
				'close' => (int)Tools::getValue('close'),
				'lang' => pSQL(Tools::getValue('lang')),
			);
			Configuration::updateValue('URI_CLIMATE', serialize($data));
			$this->_clearCache('footer.tpl');
            return $this->displayConfirmation($this->l('Settings updated'));
        }
    }

    private function getForm()
	{
        $helper = new HelperForm();
        $helper->module = $this;
        $helper->name_controller = $this->name;
        $helper->identifier = $this->identifier;
        $helper->token = Tools::getAdminTokenLite('AdminModules');
        $helper->languages = $this->context->controller->getLanguages();
        $helper->currentIndex = AdminController::$currentIndex . '&configure=' . $this->name;
        $helper->default_form_language = $this->context->controller->default_form_language;
        $helper->allow_employee_form_lang = $this->context->controller->allow_employee_form_lang;
        $helper->title = $this->displayName;

		$data = unserialize(Configuration::get('URI_CLIMATE'));
		$helper->fields_value = array(
			'cookie' => (int)$data['cookie'],
			'analytics' => (int)$data['analytics'],
			'show' => (int)$data['show'],
			'full' => (int)$data['full'],
			'close' => (int)$data['close'],
			'lang' => pSQL($data['lang']),
		);
		
		$accepted = array(
			array('id' => 'en', 'name' => $this->l('English')),
			array('id' => 'es', 'name' => $this->l('Spanish')),
			array('id' => 'de', 'name' => $this->l('German')),
			array('id' => 'cs', 'name' => $this->l('Czech')),
			array('id' => 'fr', 'name' => $this->l('French')),
			array('id' => 'nl', 'name' => $this->l('Dutch')),
			array('id' => 'tr', 'name' => $this->l('Turkish')),
			array('id' => 'pt', 'name' => $this->l('Portuguese')),
		);

        $helper->submit_action = 'submit';
        $this->form[] = array(
            'form' => array(
                'legend' => array(
                    'title' => $this->displayName
                ),
                'input' => array(
					array(
						'type' => 'text',
						'label' => $this->l('Duración de la cookie'),
						'desc' => $this->l('¿Cuantos días tardará en volver a aparecer el mensaje?'),
						'name' => 'cookie',
						'lang' => false,
					),
					array(
						'type' => 'switch',
						'label' => $this->l('¿Desactivar Analytics?'),
						'name' => 'analytics',
						'values' => array(
							array(
								'id' => 'analytics_on',
								'value' => 1,
								'label' => $this->l('Yes')
							),
							array(
								'id' => 'analytics_off',
								'value' => 0,
								'label' => $this->l('No')
							)
						),
					),
					array(
						'type' => 'switch',
						'label' => $this->l('¿Forzar diseño de pantalla completa?'),
						'name' => 'full',
						'values' => array(
							array(
								'id' => 'full_on',
								'value' => 1,
								'label' => $this->l('Yes')
							),
							array(
								'id' => 'full_off',
								'value' => 0,
								'label' => $this->l('No')
							)
						),
					),
					array(
						'type' => 'switch',
						'label' => $this->l('¿Mostrar botón de cerrar?'),
						'name' => 'close',
						'values' => array(
							array(
								'id' => 'close_on',
								'value' => 1,
								'label' => $this->l('Yes')
							),
							array(
								'id' => 'close_off',
								'value' => 0,
								'label' => $this->l('No')
							)
						),
					),
					array(
						'type' => 'switch',
						'label' => $this->l('¿Mostrar Siempre el Widget?'),
						'desc' => $this->l('Aunque el cliente haya pulsado el botón de cerrar'),
						'name' => 'show',
						'values' => array(
							array(
								'id' => 'show_on',
								'value' => 1,
								'label' => $this->l('Yes')
							),
							array(
								'id' => 'show_off',
								'value' => 0,
								'label' => $this->l('No')
							)
						),
					),
					array(
                        'type'  => 'select',
                        'label' => $this->l('Idioma por defecto'),
                        'desc' => $this->l('Si el idioma de la web no está disponible saldrá el seleccionado'),
                        'name'  => 'lang',
						'multiple' => false,
                        'options' => array(
                            'query' => $accepted,
                            'id' => 'id',
                            'name' => 'name',
                        )
                    ),
				),
                'submit' => array(
                    'title' => $this->l('Save')
                )
            )
        );

        return $helper->generateForm($this->form);
    }
		
    public function hookDisplayFooter()
	{
		if (!$this->isCached('footer.tpl', $this->getCacheId())) {
			$data = unserialize(Configuration::get('URI_CLIMATE'));
			$accepted = array('en','de','es','cs','fr','nl','tr','pt');
			$lang = strtolower($this->context->language->iso_code);
			if(Configuration::get('PS_SSL_ENABLED') == 1){
				$base_url = _PS_BASE_URL_SSL_;
			} else {
				$base_url = _PS_BASE_URL_;
			}
			$climate = array(
				'lang' => in_array($lang, $accepted) ? $lang : $data['lang'],
				'cookie' => (int)$data['cookie'],
				'analytics' => $data['analytics'] == 1 ? 'true' : 'false',
				'show' => $data['show'] == 1 ? 'true' : 'false',
				'full' => $data['full'] == 1 ? 'true' : 'false',
				'close' => $data['close'] == 1 ? 'true' : 'false',
				'widget' => $base_url.'/modules/uriclimate/views/templates/js/widget.js',
			);
			$this->context->smarty->assign(array('climate' => $climate));
		}
		return $this->display(__FILE__, 'footer.tpl', $this->getCacheId());
    }
}